require 'spec_helper'

describe Quandl::Cassandra::Base::Persistence do
  
  let(:id){ Cql::Uuid.new(SecureRandom.uuid) }
  
  subject{ Post.new }
  
  it{ should respond_to :id }
  it{ should respond_to :content }
  it{ should respond_to :author }
  it{ should respond_to :updated_at }
  
  its(:new_record?){ should be_true }
  
  describe ".new_from_query_result" do
    subject{ Post.new_from_query_result({ id: id, content: 'blah', author: 'someone' }) }
    
    its(:changes){ should be_blank }
    its(:id){ should eq id }
    its(:content){ should eq 'blah' }
    its(:author){ should eq 'someone' }
  end
  
  describe ".create" do
    
    let(:post){ Post.create( id: id, content: 'test content', author: "quandl" ) }
    subject{ post }
    
    its(:new_record?){ should be_false }
    
    describe ".find" do
      subject{ Post.find(post.id) }
      
      its(:id){ should eq id }
      its(:content){ should eq 'test content' }
      its(:author){ should eq 'quandl' }
      its(:new_record?){ should be_false }
      its(:changes){ should be_blank }
      its(:changed?){ should be_false }
    end
    
    describe ".destroy" do
      before(:each){ post.destroy }
      it "should not find the post" do
        Post.find(post.id).should be_nil
      end
    end
    
    describe ".delete" do
      before(:each){ post.delete }
      it "should not find the post" do
        Post.find(post.id).should be_nil
      end
    end
    
  end
  
end