require 'spec_helper'

describe Quandl::Cassandra::Base::Scoping do
  
  before(:all){ 
    Post.truncate
    5.times{ create(:post) } 
  }
  let(:posts){ Post.all }
  
  subject{ Post }
  
  [:where, :select, :limit, :order].each do |name|
    it{ should respond_to name }
  end
  
  let(:id){ SecureRandom.uuid }
  
  its(:scope_names){ should eq Post.scope.scope_names }
  
  describe ".all" do
    
    subject{ posts }
    its(:count){ should eq 5 }
    
    describe "#first" do
      subject{ posts.first }
      
      its(:changes){ should be_blank }
      its(:id){ should be_a Cql::Uuid }
    end
  end
  
  describe ".where" do
    
    let(:ids){ posts.collect(&:id)[1..3] }
    subject{ Post.where(id: ids ) }

    its(:count){ should eq 3 }
    
    describe "#first" do
      subject{ posts.first }
      
      its(:changes){ should be_blank }
      its(:id){ should be_a Cql::Uuid }
    end
    
  end
  
  describe ".find_or_build" do
    it "given nil should be a new record" do
      Post.find_or_build(nil).new_record?.should be_true
    end
    it "given empty sting should be a new record" do
      Post.find_or_build('').new_record?.should be_true
    end
  end
  
  describe ".to_cql" do
    
    let(:scope) { Post.scope.new }
    subject{ scope.to_cql }
  
    describe "#where" do
      before(:each){ scope.where( id: id ) }
      it{ should eq "SELECT * FROM posts WHERE id = #{id}" }

      describe "#limit" do
        before(:each){ scope.limit( 10 ) }
        it{ should eq "SELECT * FROM posts WHERE id = #{id} LIMIT 10" }

        describe "#select" do
          before(:each){ scope.select( :name, :value ) }
          it{ should eq "SELECT name,value FROM posts WHERE id = #{id} LIMIT 10" }
        
          describe "#order" do
            before(:each){ scope.order("name DESC") }
            it{ should eq "SELECT name,value FROM posts WHERE id = #{id} ORDER BY name DESC LIMIT 10" }
          end
        
        end
      end
    end
  end
  
end